package com.sun.jndi.ldap;

import javax.naming.NamingException;
import java.util.ArrayList;
import com.sun.jndi.ldap.spi.LdapDnsProviderResult;
import java.util.Optional;
import java.util.Map;

public class DefaultLdapDnsProvider
{
    public DefaultLdapDnsProvider() {
    }
    
    public Optional<LdapDnsProviderResult> lookupEndpoints(String s, Map<?, ?> map) throws NamingException {
        if (s == null || map == null) {
            throw new NullPointerException();
        }
        ArrayList<String> list = new ArrayList();
        LdapURL ldapURL = new LdapURL(s);
        String dn = ldapURL.getDN();
        String host = ldapURL.getHost();
        int port = ldapURL.getPort();
        String mapDnToDomainName;
        String[] ldapService;
        if (host == null && port == -1 && dn != null && (mapDnToDomainName = ServiceLocator.mapDnToDomainName(dn)) != null && (ldapService = ServiceLocator.getLdapService(mapDnToDomainName, map)) != null) {
            String string = ldapURL.getScheme() + "://";
            String query = ldapURL.getQuery();
            String string2 = ldapURL.getPath() + ((query != null) ? query : "");
            for (int length = ldapService.length, i = 0; i < length; ++i) {
                list.add(string + ldapService[i] + string2);
            }
        }
        else {
            mapDnToDomainName = "";
            list.add(s);
        }
        LdapDnsProviderResult value = new LdapDnsProviderResult(mapDnToDomainName, list);
        if (value.getEndpoints().size() == 0 && value.getDomainName().isEmpty()) {
            return Optional.empty();
        }
        return Optional.of(value);
    }
}
